pub enum DurableBackgroundSubagentExecutionStatus {
Accepted,
Starting,
Running,
Waiting,
Completed,
Failed,
Cancelled,
}Expand description
Monotonic durable execution state for one background attempt.
Variants
Accepted
Identity, quota, ownership, and durable admission exist.
Starting
Child construction is in progress.
Running
Child execution can make progress.
Waiting
The same attempt is waiting for an explicitly resumable condition.
Completed
Child execution completed successfully.
Failed
Child execution failed or was interrupted after process loss.
Cancelled
Child execution was cancelled.
Implementations