pub enum InputConversionError {
LegacyContent(Error),
ProductMode(String),
ProductCommand(String),
}Expand description
Failure converting legacy durable input into canonical model content.
Variants
LegacyContent(Error)
Previous content-part escape hatch contains invalid content JSON.
ProductMode(String)
Product mode must be handled before runtime input conversion.
ProductCommand(String)
Product command must be handled before runtime input conversion.