pub enum SessionSearchIndexError {
InvalidMutation(String),
Unavailable(String),
Failed(String),
}Expand description
Index-publication errors.
Variants
InvalidMutation(String)
Mutation is invalid or conflicts with a stable event identity.
Index is temporarily unavailable and the durable outbox should retry.
Failed(String)
Safe bounded failure.