pub enum SessionSearchVisibility {
Public,
Diagnostic,
Internal,
}Expand description
Display visibility classes that a host may permit.
Variants
Public
Ordinary user-visible display text.
Diagnostic
Diagnostic text, only when a host explicitly permits it.
Internal
Internal text, only when a host explicitly permits it.