pub struct BackgroundSubagentArtifactLimits {
pub max_single_bytes: u64,
pub max_retained_bytes: u64,
}Expand description
Host policy limits applied atomically to retained result artifacts.
Fields
max_single_bytes: u64Maximum bytes accepted for one artifact.
max_retained_bytes: u64Maximum aggregate unexpired artifact bytes in one durable namespace.
Implementations