CompactRunTrace

Struct CompactRunTrace 

pub struct CompactRunTrace {
Show 15 fields pub session_id: Option<SessionId>, pub run_id: Option<RunId>, pub status: RunStatus, pub parent_run_id: Option<RunId>, pub parent_task_id: Option<TaskId>, pub checkpoints: Vec<CheckpointId>, pub approvals: usize, pub deferred_tools: usize, pub latest_checkpoint: Option<CheckpointId>, pub stream_cursor: Option<usize>, pub stream_cursors: Vec<StreamCursorRef>, pub output_preview: Option<String>, pub trace_context: TraceContext, pub updated_at: Option<DateTime<Utc>>, pub metadata: Metadata,
}
Compact run projection for tools, CLI, and UI.

Fields

session_id: Option<SessionId>

Session id.

run_id: Option<RunId>

Run id.

status: RunStatus

Durable run status.

parent_run_id: Option<RunId>

Parent run identifier when this trace belongs to a delegated child run.

parent_task_id: Option<TaskId>

Parent-scoped delegated task identifier when this trace belongs to a lightweight task.

checkpoints: Vec<CheckpointId>

Checkpoint ids in insertion order.

approvals: usize

Approval count.

deferred_tools: usize

Deferred tool count.

latest_checkpoint: Option<CheckpointId>

Latest checkpoint id.

stream_cursor: Option<usize>

Latest persisted stream cursor.

stream_cursors: Vec<StreamCursorRef>

Stream cursor references.

output_preview: Option<String>

Output preview.

trace_context: TraceContext

Trace context.

updated_at: Option<DateTime<Utc>>

Last update time.

metadata: Metadata

Trace metadata.