pub struct DurableBackgroundSubagentResultRef {
pub content: Option<String>,
pub error: Option<String>,
pub artifact_ref: Option<String>,
pub digest: Option<String>,
pub size_bytes: u64,
}Expand description
Bounded terminal result material retained by the durable host.
Fields
content: Option<String>Bounded successful text content.
error: Option<String>Bounded safe error text.
artifact_ref: Option<String>Optional host artifact locator for oversized content.
digest: Option<String>Stable digest of the retained logical content when available.
size_bytes: u64Logical content size before host retention policy was applied.