pub struct DurableRunStatus(/* private fields */);Expand description
Durable run status composed from admission state and the shared runtime lifecycle.
Implementations
Sourceimpl DurableRunStatus
impl DurableRunStatus
Sourcepub const fn lifecycle(self) -> Option<RunLifecycle>
pub const fn lifecycle(self) -> Option<RunLifecycle>
Return the admitted runtime lifecycle, or None while queued.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Return whether the run reached a terminal lifecycle.