pub struct SessionStoreExecutor { /* private fields */ }Expand description
Executor adapter that persists runtime checkpoints into a session store.
Implementations
Sourceimpl SessionStoreExecutor
impl SessionStoreExecutor
Sourcepub fn new(store: Arc<dyn SessionStore>, session_id: SessionId) -> Self
pub fn new(store: Arc<dyn SessionStore>, session_id: SessionId) -> Self
Create a checkpoint executor for one session.
Sourcepub fn new_fenced(
store: Arc<dyn SessionStore>,
session_id: SessionId,
admission_lease: RunAdmissionLease,
) -> Self
pub fn new_fenced( store: Arc<dyn SessionStore>, session_id: SessionId, admission_lease: RunAdmissionLease, ) -> Self
Create a checkpoint executor fenced to one active run admission.
Sourcepub const fn session_id(&self) -> &SessionId
pub const fn session_id(&self) -> &SessionId
Return the session id associated with this executor.